Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(271)

Unified Diff: webrtc/p2p/base/port.h

Issue 1868353004: Update prflx candidates' generation when setting ICE credentials. (Closed) Base URL: https://chromium.googlesource.com/external/webrtc.git@master
Patch Set: Only need to pass in the last ICE params and the generation. Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « webrtc/p2p/base/p2ptransportchannel_unittest.cc ('k') | webrtc/p2p/base/port.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webrtc/p2p/base/port.h
diff --git a/webrtc/p2p/base/port.h b/webrtc/p2p/base/port.h
index 7c4468d2e6b7d112abf7a4b93f41b9645e5f86c3..2961355e3e1cf839689eeb72ad143c7f3c7960cb 100644
--- a/webrtc/p2p/base/port.h
+++ b/webrtc/p2p/base/port.h
@@ -574,10 +574,14 @@ class Connection : public CandidatePairInterface,
uint32_t ComputeNetworkCost() const;
- // Update the ICE password of the remote candidate if |ice_ufrag| matches
- // the candidate's ufrag, and the candidate's passwrod has not been set.
- void MaybeSetRemoteIceCredentials(const std::string& ice_ufrag,
- const std::string& ice_pwd);
+ // Update the ICE password and/or generation of the remote candidate if a
+ // ufrag in |remote_ice_parameters| matches the candidate's ufrag, and the
+ // candidate's password and/or ufrag has not been set.
+ // |remote_ice_parameters| should be a list of known ICE parameters ordered
+ // by generation.
+ void MaybeSetRemoteIceCredentialsAndGeneration(const std::string& ice_ufrag,
+ const std::string& ice_pwd,
+ int generation);
// If |remote_candidate_| is peer reflexive and is equivalent to
// |new_candidate| except the type, update |remote_candidate_| to
« no previous file with comments | « webrtc/p2p/base/p2ptransportchannel_unittest.cc ('k') | webrtc/p2p/base/port.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698